MutualProximity — scikit-hubness 0.21a1 documentation

# MutualProximity

class `skhubness.reduction.` `MutualProximity`(k: int = 5, method: str = 'normal', verbose: int = 0)

  Bases: `object`

  Hubness reduction with Mutual Proximity.

  Methods Summary

  `fit`(self, neigh_dist, neigh_ind, \*args, …) |
  `transform`(self, neigh_dist, neigh_ind, …) |

  Methods Documentation

  `fit`(self, neigh_dist, neigh_ind, *args, **kwargs) → 'MutualProximity'
  `transform`(self, neigh_dist, neigh_ind, *args, **kwargs)